#######
Install
#######

| The easiest way to install passy is to use python's pip module
|
| Use this command in your terminal

Using pip::

    pip install passy

    or

    python -m pip install passy

| If you get an error use the documentation to reinstall your `pip`_

.. _pip: https://pip.pypa.io/en/stable/installing/